aboutsummaryrefslogtreecommitdiff
path: root/lib/fsusage.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/fsusage.h')
-rw-r--r--lib/fsusage.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/lib/fsusage.h b/lib/fsusage.h
index e2cbbf12..f3eda2d0 100644
--- a/lib/fsusage.h
+++ b/lib/fsusage.h
@@ -1,6 +1,7 @@
-/* fsusage.h -- declarations for filesystem space usage info
+/* fsusage.h -- declarations for file system space usage info
- Copyright (C) 1991, 1992, 1997, 2003 Free Software Foundation, Inc.
+ Copyright (C) 1991, 1992, 1997, 2003, 2004, 2005 Free Software
+ Foundation, Inc.
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -14,24 +15,26 @@
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
- Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+ Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. */
-/* Space usage statistics for a filesystem. Blocks are 512-byte. */
+/* Space usage statistics for a file system. Blocks are 512-byte. */
#if !defined FSUSAGE_H_
# define FSUSAGE_H_
+# include <stdbool.h>
+
struct fs_usage
{
- int fsu_blocksize; /* Size of a block. */
+ uintmax_t fsu_blocksize; /* Size of a block. */
uintmax_t fsu_blocks; /* Total blocks. */
uintmax_t fsu_bfree; /* Free blocks available to superuser. */
uintmax_t fsu_bavail; /* Free blocks available to non-superuser. */
- int fsu_bavail_top_bit_set; /* 1 if fsu_bavail represents a value < 0. */
+ bool fsu_bavail_top_bit_set; /* 1 if fsu_bavail represents a value < 0. */
uintmax_t fsu_files; /* Total file nodes. */
uintmax_t fsu_ffree; /* Free file nodes. */
};
-int get_fs_usage (const char *path, const char *disk, struct fs_usage *fsp);
+int get_fs_usage (char const *file, char const *disk, struct fs_usage *fsp);
#endif